function m = read_model()
%% Read and solve model
% by Jaromir Benes
%
% In this m-file, we create a model object by loading a model file, assign
% parameters to the model object, find its steady state, and compute
% first-order accurate solution. This will make the model ready for further
% experiments.

%% Clear workspace

home();
clear();
close('all');

%% Read model file and create model object

m = model('simple_SPBC.model','removeleads',true);

m.alpha = 1.03^(1/4);
m.beta = 0.985^(1/4);
m.gamma = 0.60;
m.delta = 0.03;
m.pi = 1.025^(1/4);
m.eta = 6;
m.k = 10;
m.psi = 0.25;

m.chi = 0.85;
m.xiw = 60;
m.xip = 300;
m.rhoa = 0.90;

m.rhor = 0.85;
m.kappap = 3.5;
m.kappan = 0;

m.Short_ = 0;
m.Infl_ = 0;
m.Growth_ = 0;
m.Wage_ = 0;

m.std_Mp = 0.00;
m.std_Mw = 0.00;
m.std_Ea = 0.01;

get(m,'parameters')

%% Compute steady state

m = sstate(m,'growth',true,'blocks',true,'display','iter');

[flag,list] = chksstate(m);
flag

if ~flag
   error('\n*** Steady-state error in ''%s''.',list{:});
end

%% Compute first-order solution

m = solve(m)

%% Save model object

save('read_model.mat','m');
end
%% Help on IRIS functions used in this m-file
%
% Use either |help| to display help in the command window, or |idoc|
% to display help in a HTML browser window.
%
%    help model/model
%    help model/subsasgn
%    help model/assign
%    help model/sstate
%    help model/chksstate
%    help model/solve
